@@ -1,10 +1,11 @@
 """
     Log
 """
-__author__ = ('Reza Zeiny <rezazeiny1998@gmail.com>',)
+__author__ = ("Reza Zeiny <rezazeiny1998@gmail.com>",)
 
 import json
 import logging
+import sys
 from typing import List, Optional
 
 import requests
@@ -73,7 +74,7 @@ class Logger:
     extra_data: dict = None
 
     log_level: int = INFO
-    log_format = '%(datetime)s %(level)s%(process_thread)s%(file_detail)s%(text)s'
+    log_format = "%(datetime)s %(level)s%(process_thread)s%(file_detail)s%(text)s"
 
     colorful: bool = True
     show_datetime: bool = True
@@ -324,12 +325,13 @@ class LogstashHandler(logging.Handler):
     """
         A handler class which send data to logstash.
     """
-    EXTRA_FIELDS = ['name', 'msg', 'args', 'levelname', 'levelno', 'pathname', 'filename', 'module', 'exc_info',
-                    'exc_text', 'stack_info', 'lineno', 'funcName', 'created', 'msecs', 'relativeCreated', 'thread',
-                    'threadName', 'processName', 'process', 'message']
-    LOGGER_DATA = ['name', 'levelname', 'levelno', 'pathname', 'filename', 'module', 'exc_info',
-                   'exc_text', 'stack_info', 'lineno', 'funcName', 'created', 'msecs', 'relativeCreated', 'thread',
-                   'threadName', 'processName', 'process']
+    EXTRA_FIELDS = ["name", "msg", "args", "levelname", "levelno", "pathname", "filename", "module", "exc_info",
+                    "exc_text", "stack_info", "lineno", "funcName", "created", "msecs", "relativeCreated", "thread",
+                    "threadName", "processName", "process", "message",
+                    "logger_data", "extra_data", "short_message", "app_name", "host_name"]
+    LOGGER_DATA = ["name", "levelname", "levelno", "pathname", "filename", "module", "exc_info",
+                   "exc_text", "stack_info", "lineno", "funcName", "created", "msecs", "relativeCreated", "thread",
+                   "threadName", "processName", "process"]
 
     def __init__(self, log_server: str, app_name: str = None, host_name: str = None, extra_data: dict = None):
         super().__init__()
@@ -350,7 +352,7 @@ class LogstashHandler(logging.Handler):
     def get_send_data(self, record: logging.LogRecord):
         send_data = {
             "logger_data": self.get_logger_data(record=record),
-            "short_message": record.message,
+            "short_message": record.getMessage(),
         }
         if self.app_name is not None:
             send_data["app_name"] = self.app_name
@@ -359,13 +361,9 @@ class LogstashHandler(logging.Handler):
         if self.extra_data is not None:
             send_data["extra_data"] = self.extra_data
 
-        record_dict = record.__dict__
-        for key in self.EXTRA_FIELDS:
-            if key in record_dict:
-                record_dict.pop(key)
-        for key, value in record_dict.items():
-            if str(key) not in ["logger_data", "extra_data", "short_message", "app_name", "host_name"]:
-                send_data[str(key)] = value
+        for key, value in record.__dict__.items():
+            if key not in self.EXTRA_FIELDS:
+                send_data[key] = value
         return send_data
 
     def send(self, send_data: dict):
@@ -386,32 +384,16 @@ class LogstashHandler(logging.Handler):
 
         except RecursionError:  # See issue 36272
             raise
-        except Exception:
-            self.handleError(record)
+        except Exception as e:
+            if sys.stderr:
+                sys.stderr.write(f"error in send to logstash {self.log_server}. e: {e}")
 
 
 class ColorfulStreamHandler(logging.StreamHandler):
     """
         A handler class which write stram handler.
     """
-    show_datetime: bool = True
-    datetime_color: "Colors" = Colors.GREEN_F
-
-    file_depth: int = 1
-    show_file: bool = True
-    show_line: bool = True
-    show_func: bool = True
-    show_logger_name: bool = True
-    file_color: "Colors" = Colors.MAGENTA_F
-
-    show_process_name: bool = False
-    show_process_id: bool = False
-    show_thread_name: bool = False
-    show_thread_id: bool = False
-    process_thread_color: "Colors" = Colors.BLUE_F
-
-    show_level: bool = True
-    level_detail = {
+    LEVEL_COLOR_DATA = {
         NOTSET: ("NOTSET   ", Colors.CYAN_F),
         CRITICAL: ("CRITICAL ", Colors.BRIGHT_RED_F),
         ERROR: ("ERROR    ", Colors.RED_F),
@@ -420,13 +402,34 @@ class ColorfulStreamHandler(logging.StreamHandler):
         DEBUG: ("DEBUG    ", Colors.BRIGHT_MAGENTA_F),
     }
 
-    def __init__(self, log_format: str = None, colorful: bool = True):
+    def __init__(self, colorful: bool = True, show_level: bool = True,
+                 show_datetime: bool = True, datetime_color: "Colors" = Colors.GREEN_F,
+
+                 show_logger_name: bool = True, file_depth: int = 1, show_file: bool = True,
+                 show_line: bool = True, show_func: bool = True, file_color: "Colors" = Colors.MAGENTA_F,
+
+                 show_process_name: bool = False, show_process_id: bool = False,
+                 show_thread_name: bool = False, show_thread_id: bool = False,
+                 process_thread_color: "Colors" = Colors.BLUE_F):
         super().__init__()
-        if log_format is None:
-            log_format = '%(datetime)s %(level)s%(process_thread)s%(file_detail)s%(text)s'
-        self.log_format = log_format
-        self.setFormatter(logging.Formatter(self.log_format))
         self.colorful = colorful
+        self.show_level = show_level
+
+        self.show_datetime = show_datetime
+        self.datetime_color = datetime_color
+
+        self.show_logger_name = show_logger_name
+        self.file_depth = file_depth
+        self.show_file = show_file
+        self.show_line = show_line
+        self.show_func = show_func
+        self.file_color = file_color
+
+        self.show_process_name = show_process_name
+        self.show_process_id = show_process_id
+        self.show_thread_name = show_thread_name
+        self.show_thread_id = show_thread_id
+        self.process_thread_color = process_thread_color
 
     def get_color_text(self, text, color: Optional[Colors]):
         """
@@ -481,31 +484,29 @@ class ColorfulStreamHandler(logging.StreamHandler):
             Get Level
         """
         return get_inner_detail([
-            (self.show_level, self.level_detail.get(record.levelno, ("",))[0])
+            (self.show_level, self.LEVEL_COLOR_DATA.get(record.levelno, ("",))[0])
         ])
 
     def get_level_color(self, record):
         """
             Get Level Color
         """
-        return self.level_detail.get(record.levelno, ("", Colors.YELLOW_B))[1]
+        return self.LEVEL_COLOR_DATA.get(record.levelno, ("", Colors.YELLOW_B))[1]
 
     def emit(self, record: logging.LogRecord) -> None:
         try:
-            record.message = record.getMessage()
-            record.datetime = self.get_color_text(self.get_datetime(), color=self.datetime_color)
-            record.process_thread = self.get_color_text(self.get_process_thread(record),
-                                                        color=self.process_thread_color)
-            record.file_detail = self.get_color_text(self.get_file_detail(record), color=self.file_color)
-
             color = self.get_level_color(record)
-            record.level = self.get_color_text(self.get_level(record), color=color)
-            record.text = self.get_color_text(record.message, color=color)
 
-            message = self.format(record)
+            color_datetime = self.get_color_text(self.get_datetime(), color=self.datetime_color)
+            color_level = self.get_color_text(self.get_level(record), color=color)
+            color_process_thread = self.get_color_text(self.get_process_thread(record),
+                                                       color=self.process_thread_color)
+            color_file_detail = self.get_color_text(self.get_file_detail(record), color=self.file_color)
+            color_text = self.get_color_text(record.getMessage(), color=color)
+
+            message = f"{color_datetime} {color_level}{color_process_thread}{color_file_detail}{color_text}"
 
             stream = self.stream
-            # issue 35046: merged two stream.writes into one.
             stream.write(message + self.terminator)
             self.flush()
         except RecursionError:  # See issue 36272
